@@ -4,7 +4,7 @@
 #' \code{wflow_html} has two distinct functionalities: 1) configure the
 #' formatting of the HTML by extending \code{\link[rmarkdown]{html_document}}
 #' (see the
-#' \href{https://rmarkdown.rstudio.com/html_document_format.html}{RStudio
+#' \href{https://bookdown.org/yihui/rmarkdown/html-document.html}{RStudio
 #' documentation} for the available options), and 2) configure the workflowr
 #' reproducibility features (typically specified in a file named
 #' \code{_workflowr.yml}). \code{wflow_html} is intended to be used to generate
@@ -19,7 +19,7 @@
 #' \code{analysis/_site.yml}. This special file can also be used to configure
 #' other aspects of the website like the navigation bar (for more details see
 #' the documentation on
-#' \href{https://rmarkdown.rstudio.com/rmarkdown_websites.html}{R Markdown
+#' \href{https://bookdown.org/yihui/rmarkdown/rmarkdown-site.html}{R Markdown
 #' websites}). For example, to use the theme "cosmo" and add a table of contents
 #' to every webpage, you would add the following to \code{analysis/_site.yml}:
 #'
@@ -66,7 +66,7 @@
 #'   \code{\link[rmarkdown]{render}}. By default, \code{\link{wflow_start}} sets
 #'   \code{knit_root_dir} in the file \code{_workflowr.yml} to be the path
 #'   \code{"."}. This path is a
-#'   \href{https://swcarpentry.github.io/shell-novice/reference/#relative-path}{relative
+#'   \href{https://swcarpentry.github.io/shell-novice/reference.html#relative-path}{relative
 #'   path} from the location of \code{_workflowr.yml} to the directory for the
 #'   code to be executed. The path \code{"."} is shorthand for "current working
 #'   directory", and thus code is executed in the root of the workflowr project.
@@ -554,13 +554,6 @@ add_pagetitle <- function(metadata, input_file) {
   # No pagetitle
   if (!is.null(metadata$pagetitle)) return(character(0))
 
-  # rmarkdown version that does not adds pagetitle
-  rmd_version <- utils::packageVersion("rmarkdown")
-  # rmarkdown handles this starting in version 1.10 and ending in version 1.18
-  # https://github.com/rstudio/rmarkdown/pull/1355
-  if (rmd_version >= "1.10" && rmd_version <= "1.17")
-    return(character(0))
-
   # No title/pagetitle defined with pandoc_args
   if (is.list(metadata$output)) {
       pandoc_args <- metadata$output$`workflowr::wflow_html`$pandoc_args
